function [score, sneg, spos] = kdeClass(d,N,P)
%KDECLASS - Kernel Density Estimator classifier
%
% [SCORE, SNEG, SPOS] = KDECLASS(D,N,P)  
%
% D - test data matrix, each column is a datapoint
% N - negative data matrix
% P - positive data matrix
%
% SCORE(I) - log ratio of positive vs negative scores
%

[negscore, sneg] = kde(N', d');
[posscore, spos] = kde(P', d');
score = posscore - negscore;
